# coding: utf-8

# flake8: noqa

"""
    Influx API Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import apis into sdk package
from influxdb_client.service.authorizations_service import AuthorizationsService
from influxdb_client.service.buckets_service import BucketsService
from influxdb_client.service.cells_service import CellsService
from influxdb_client.service.checks_service import ChecksService
from influxdb_client.service.dashboards_service import DashboardsService
from influxdb_client.service.health_service import HealthService
from influxdb_client.service.influx_packages_service import InfluxPackagesService
from influxdb_client.service.labels_service import LabelsService
from influxdb_client.service.notification_endpoints_service import NotificationEndpointsService
from influxdb_client.service.notification_rules_service import NotificationRulesService
from influxdb_client.service.operation_logs_service import OperationLogsService
from influxdb_client.service.organizations_service import OrganizationsService
from influxdb_client.service.query_service import QueryService
from influxdb_client.service.ready_service import ReadyService
from influxdb_client.service.rules_service import RulesService
from influxdb_client.service.scraper_targets_service import ScraperTargetsService
from influxdb_client.service.secrets_service import SecretsService
from influxdb_client.service.setup_service import SetupService
from influxdb_client.service.sources_service import SourcesService
from influxdb_client.service.tasks_service import TasksService
from influxdb_client.service.telegrafs_service import TelegrafsService
from influxdb_client.service.templates_service import TemplatesService
from influxdb_client.service.users_service import UsersService
from influxdb_client.service.variables_service import VariablesService
from influxdb_client.service.views_service import ViewsService
from influxdb_client.service.write_service import WriteService
from influxdb_client.service.default_service import DefaultService

# import ApiClient
from influxdb_client.api_client import ApiClient
from influxdb_client.configuration import Configuration
# import models into sdk package
from influxdb_client.domain.ast_response import ASTResponse
from influxdb_client.domain.add_resource_member_request_body import AddResourceMemberRequestBody
from influxdb_client.domain.analyze_query_response import AnalyzeQueryResponse
from influxdb_client.domain.analyze_query_response_errors import AnalyzeQueryResponseErrors
from influxdb_client.domain.array_expression import ArrayExpression
from influxdb_client.domain.authorization import Authorization
from influxdb_client.domain.authorization_update_request import AuthorizationUpdateRequest
from influxdb_client.domain.authorizations import Authorizations
from influxdb_client.domain.axes import Axes
from influxdb_client.domain.axis import Axis
from influxdb_client.domain.axis_scale import AxisScale
from influxdb_client.domain.bad_statement import BadStatement
from influxdb_client.domain.binary_expression import BinaryExpression
from influxdb_client.domain.block import Block
from influxdb_client.domain.boolean_literal import BooleanLiteral
from influxdb_client.domain.bucket import Bucket
from influxdb_client.domain.bucket_links import BucketLinks
from influxdb_client.domain.bucket_retention_rules import BucketRetentionRules
from influxdb_client.domain.buckets import Buckets
from influxdb_client.domain.builder_config import BuilderConfig
from influxdb_client.domain.builder_config_aggregate_window import BuilderConfigAggregateWindow
from influxdb_client.domain.builder_functions_type import BuilderFunctionsType
from influxdb_client.domain.builder_tags_type import BuilderTagsType
from influxdb_client.domain.builtin_statement import BuiltinStatement
from influxdb_client.domain.call_expression import CallExpression
from influxdb_client.domain.cell import Cell
from influxdb_client.domain.cell_links import CellLinks
from influxdb_client.domain.cell_update import CellUpdate
from influxdb_client.domain.check import Check
from influxdb_client.domain.check_base import CheckBase
from influxdb_client.domain.check_base_links import CheckBaseLinks
from influxdb_client.domain.check_base_tags import CheckBaseTags
from influxdb_client.domain.check_discriminator import CheckDiscriminator
from influxdb_client.domain.check_patch import CheckPatch
from influxdb_client.domain.check_status_level import CheckStatusLevel
from influxdb_client.domain.check_view_properties import CheckViewProperties
from influxdb_client.domain.checks import Checks
from influxdb_client.domain.conditional_expression import ConditionalExpression
from influxdb_client.domain.constant_variable_properties import ConstantVariableProperties
from influxdb_client.domain.create_cell import CreateCell
from influxdb_client.domain.create_dashboard_request import CreateDashboardRequest
from influxdb_client.domain.dashboard import Dashboard
from influxdb_client.domain.dashboard_color import DashboardColor
from influxdb_client.domain.dashboard_query import DashboardQuery
from influxdb_client.domain.dashboards import Dashboards
from influxdb_client.domain.date_time_literal import DateTimeLiteral
from influxdb_client.domain.deadman_check import DeadmanCheck
from influxdb_client.domain.decimal_places import DecimalPlaces
from influxdb_client.domain.delete_predicate_request import DeletePredicateRequest
from influxdb_client.domain.dialect import Dialect
from influxdb_client.domain.document import Document
from influxdb_client.domain.document_create import DocumentCreate
from influxdb_client.domain.document_links import DocumentLinks
from influxdb_client.domain.document_list_entry import DocumentListEntry
from influxdb_client.domain.document_meta import DocumentMeta
from influxdb_client.domain.document_update import DocumentUpdate
from influxdb_client.domain.documents import Documents
from influxdb_client.domain.duration import Duration
from influxdb_client.domain.duration_literal import DurationLiteral
from influxdb_client.domain.error import Error
from influxdb_client.domain.expression import Expression
from influxdb_client.domain.expression_statement import ExpressionStatement
from influxdb_client.domain.field import Field
from influxdb_client.domain.file import File
from influxdb_client.domain.float_literal import FloatLiteral
from influxdb_client.domain.flux_response import FluxResponse
from influxdb_client.domain.flux_suggestion import FluxSuggestion
from influxdb_client.domain.flux_suggestions import FluxSuggestions
from influxdb_client.domain.function_expression import FunctionExpression
from influxdb_client.domain.gauge_view_properties import GaugeViewProperties
from influxdb_client.domain.greater_threshold import GreaterThreshold
from influxdb_client.domain.http_notification_endpoint import HTTPNotificationEndpoint
from influxdb_client.domain.http_notification_rule import HTTPNotificationRule
from influxdb_client.domain.http_notification_rule_base import HTTPNotificationRuleBase
from influxdb_client.domain.health_check import HealthCheck
from influxdb_client.domain.heatmap_view_properties import HeatmapViewProperties
from influxdb_client.domain.histogram_view_properties import HistogramViewProperties
from influxdb_client.domain.identifier import Identifier
from influxdb_client.domain.import_declaration import ImportDeclaration
from influxdb_client.domain.index_expression import IndexExpression
from influxdb_client.domain.integer_literal import IntegerLiteral
from influxdb_client.domain.is_onboarding import IsOnboarding
from influxdb_client.domain.label import Label
from influxdb_client.domain.label_create_request import LabelCreateRequest
from influxdb_client.domain.label_mapping import LabelMapping
from influxdb_client.domain.label_response import LabelResponse
from influxdb_client.domain.label_update import LabelUpdate
from influxdb_client.domain.labels_response import LabelsResponse
from influxdb_client.domain.language_request import LanguageRequest
from influxdb_client.domain.legend import Legend
from influxdb_client.domain.lesser_threshold import LesserThreshold
from influxdb_client.domain.line_plus_single_stat_properties import LinePlusSingleStatProperties
from influxdb_client.domain.line_protocol_error import LineProtocolError
from influxdb_client.domain.line_protocol_length_error import LineProtocolLengthError
from influxdb_client.domain.links import Links
from influxdb_client.domain.log_event import LogEvent
from influxdb_client.domain.logical_expression import LogicalExpression
from influxdb_client.domain.logs import Logs
from influxdb_client.domain.map_variable_properties import MapVariableProperties
from influxdb_client.domain.markdown_view_properties import MarkdownViewProperties
from influxdb_client.domain.member_assignment import MemberAssignment
from influxdb_client.domain.member_expression import MemberExpression
from influxdb_client.domain.model_property import ModelProperty
from influxdb_client.domain.node import Node
from influxdb_client.domain.notification_endpoint import NotificationEndpoint
from influxdb_client.domain.notification_endpoint_base import NotificationEndpointBase
from influxdb_client.domain.notification_endpoint_base_links import NotificationEndpointBaseLinks
from influxdb_client.domain.notification_endpoint_discriminator import NotificationEndpointDiscriminator
from influxdb_client.domain.notification_endpoint_type import NotificationEndpointType
from influxdb_client.domain.notification_endpoint_update import NotificationEndpointUpdate
from influxdb_client.domain.notification_endpoints import NotificationEndpoints
from influxdb_client.domain.notification_rule import NotificationRule
from influxdb_client.domain.notification_rule_base import NotificationRuleBase
from influxdb_client.domain.notification_rule_base_links import NotificationRuleBaseLinks
from influxdb_client.domain.notification_rule_discriminator import NotificationRuleDiscriminator
from influxdb_client.domain.notification_rule_update import NotificationRuleUpdate
from influxdb_client.domain.notification_rules import NotificationRules
from influxdb_client.domain.object_expression import ObjectExpression
from influxdb_client.domain.onboarding_request import OnboardingRequest
from influxdb_client.domain.onboarding_response import OnboardingResponse
from influxdb_client.domain.operation_log import OperationLog
from influxdb_client.domain.operation_log_links import OperationLogLinks
from influxdb_client.domain.operation_logs import OperationLogs
from influxdb_client.domain.option_statement import OptionStatement
from influxdb_client.domain.organization import Organization
from influxdb_client.domain.organization_links import OrganizationLinks
from influxdb_client.domain.organizations import Organizations
from influxdb_client.domain.package import Package
from influxdb_client.domain.package_clause import PackageClause
from influxdb_client.domain.pager_duty_notification_endpoint import PagerDutyNotificationEndpoint
from influxdb_client.domain.pager_duty_notification_rule import PagerDutyNotificationRule
from influxdb_client.domain.pager_duty_notification_rule_base import PagerDutyNotificationRuleBase
from influxdb_client.domain.paren_expression import ParenExpression
from influxdb_client.domain.password_reset_body import PasswordResetBody
from influxdb_client.domain.permission import Permission
from influxdb_client.domain.permission_resource import PermissionResource
from influxdb_client.domain.pipe_expression import PipeExpression
from influxdb_client.domain.pipe_literal import PipeLiteral
from influxdb_client.domain.pkg import Pkg
from influxdb_client.domain.pkg_apply import PkgApply
from influxdb_client.domain.pkg_chart import PkgChart
from influxdb_client.domain.pkg_create import PkgCreate
from influxdb_client.domain.pkg_create_resources import PkgCreateResources
from influxdb_client.domain.pkg_meta import PkgMeta
from influxdb_client.domain.pkg_spec import PkgSpec
from influxdb_client.domain.pkg_summary import PkgSummary
from influxdb_client.domain.pkg_summary_diff import PkgSummaryDiff
from influxdb_client.domain.pkg_summary_diff_buckets import PkgSummaryDiffBuckets
from influxdb_client.domain.pkg_summary_diff_dashboards import PkgSummaryDiffDashboards
from influxdb_client.domain.pkg_summary_diff_label_mappings import PkgSummaryDiffLabelMappings
from influxdb_client.domain.pkg_summary_diff_labels import PkgSummaryDiffLabels
from influxdb_client.domain.pkg_summary_diff_variables import PkgSummaryDiffVariables
from influxdb_client.domain.pkg_summary_errors import PkgSummaryErrors
from influxdb_client.domain.pkg_summary_summary import PkgSummarySummary
from influxdb_client.domain.pkg_summary_summary_dashboards import PkgSummarySummaryDashboards
from influxdb_client.domain.pkg_summary_summary_label_mappings import PkgSummarySummaryLabelMappings
from influxdb_client.domain.post_bucket_request import PostBucketRequest
from influxdb_client.domain.post_check import PostCheck
from influxdb_client.domain.post_notification_endpoint import PostNotificationEndpoint
from influxdb_client.domain.post_notification_rule import PostNotificationRule
from influxdb_client.domain.property_key import PropertyKey
from influxdb_client.domain.query import Query
from influxdb_client.domain.query_edit_mode import QueryEditMode
from influxdb_client.domain.query_variable_properties import QueryVariableProperties
from influxdb_client.domain.query_variable_properties_values import QueryVariablePropertiesValues
from influxdb_client.domain.range_threshold import RangeThreshold
from influxdb_client.domain.ready import Ready
from influxdb_client.domain.regexp_literal import RegexpLiteral
from influxdb_client.domain.renamable_field import RenamableField
from influxdb_client.domain.resource_member import ResourceMember
from influxdb_client.domain.resource_members import ResourceMembers
from influxdb_client.domain.resource_owner import ResourceOwner
from influxdb_client.domain.resource_owners import ResourceOwners
from influxdb_client.domain.return_statement import ReturnStatement
from influxdb_client.domain.routes import Routes
from influxdb_client.domain.routes_external import RoutesExternal
from influxdb_client.domain.routes_query import RoutesQuery
from influxdb_client.domain.routes_system import RoutesSystem
from influxdb_client.domain.rule_status_level import RuleStatusLevel
from influxdb_client.domain.run import Run
from influxdb_client.domain.run_links import RunLinks
from influxdb_client.domain.run_log import RunLog
from influxdb_client.domain.run_manually import RunManually
from influxdb_client.domain.runs import Runs
from influxdb_client.domain.smtp_notification_rule import SMTPNotificationRule
from influxdb_client.domain.smtp_notification_rule_base import SMTPNotificationRuleBase
from influxdb_client.domain.scatter_view_properties import ScatterViewProperties
from influxdb_client.domain.scraper_target_request import ScraperTargetRequest
from influxdb_client.domain.scraper_target_response import ScraperTargetResponse
from influxdb_client.domain.scraper_target_responses import ScraperTargetResponses
from influxdb_client.domain.secret_keys import SecretKeys
from influxdb_client.domain.secret_keys_response import SecretKeysResponse
from influxdb_client.domain.single_stat_view_properties import SingleStatViewProperties
from influxdb_client.domain.slack_notification_endpoint import SlackNotificationEndpoint
from influxdb_client.domain.slack_notification_rule import SlackNotificationRule
from influxdb_client.domain.slack_notification_rule_base import SlackNotificationRuleBase
from influxdb_client.domain.source import Source
from influxdb_client.domain.source_links import SourceLinks
from influxdb_client.domain.sources import Sources
from influxdb_client.domain.statement import Statement
from influxdb_client.domain.status_rule import StatusRule
from influxdb_client.domain.string_literal import StringLiteral
from influxdb_client.domain.table_view_properties import TableViewProperties
from influxdb_client.domain.tag_rule import TagRule
from influxdb_client.domain.task import Task
from influxdb_client.domain.task_create_request import TaskCreateRequest
from influxdb_client.domain.task_links import TaskLinks
from influxdb_client.domain.task_status_type import TaskStatusType
from influxdb_client.domain.task_update_request import TaskUpdateRequest
from influxdb_client.domain.tasks import Tasks
from influxdb_client.domain.telegraf import Telegraf
from influxdb_client.domain.telegraf_plugin_input_cpu import TelegrafPluginInputCpu
from influxdb_client.domain.telegraf_plugin_input_disk import TelegrafPluginInputDisk
from influxdb_client.domain.telegraf_plugin_input_diskio import TelegrafPluginInputDiskio
from influxdb_client.domain.telegraf_plugin_input_docker import TelegrafPluginInputDocker
from influxdb_client.domain.telegraf_plugin_input_docker_config import TelegrafPluginInputDockerConfig
from influxdb_client.domain.telegraf_plugin_input_file import TelegrafPluginInputFile
from influxdb_client.domain.telegraf_plugin_input_file_config import TelegrafPluginInputFileConfig
from influxdb_client.domain.telegraf_plugin_input_kernel import TelegrafPluginInputKernel
from influxdb_client.domain.telegraf_plugin_input_kubernetes import TelegrafPluginInputKubernetes
from influxdb_client.domain.telegraf_plugin_input_kubernetes_config import TelegrafPluginInputKubernetesConfig
from influxdb_client.domain.telegraf_plugin_input_log_parser import TelegrafPluginInputLogParser
from influxdb_client.domain.telegraf_plugin_input_log_parser_config import TelegrafPluginInputLogParserConfig
from influxdb_client.domain.telegraf_plugin_input_mem import TelegrafPluginInputMem
from influxdb_client.domain.telegraf_plugin_input_net import TelegrafPluginInputNet
from influxdb_client.domain.telegraf_plugin_input_net_response import TelegrafPluginInputNetResponse
from influxdb_client.domain.telegraf_plugin_input_nginx import TelegrafPluginInputNginx
from influxdb_client.domain.telegraf_plugin_input_processes import TelegrafPluginInputProcesses
from influxdb_client.domain.telegraf_plugin_input_procstat import TelegrafPluginInputProcstat
from influxdb_client.domain.telegraf_plugin_input_procstat_config import TelegrafPluginInputProcstatConfig
from influxdb_client.domain.telegraf_plugin_input_prometheus import TelegrafPluginInputPrometheus
from influxdb_client.domain.telegraf_plugin_input_prometheus_config import TelegrafPluginInputPrometheusConfig
from influxdb_client.domain.telegraf_plugin_input_redis import TelegrafPluginInputRedis
from influxdb_client.domain.telegraf_plugin_input_redis_config import TelegrafPluginInputRedisConfig
from influxdb_client.domain.telegraf_plugin_input_swap import TelegrafPluginInputSwap
from influxdb_client.domain.telegraf_plugin_input_syslog import TelegrafPluginInputSyslog
from influxdb_client.domain.telegraf_plugin_input_syslog_config import TelegrafPluginInputSyslogConfig
from influxdb_client.domain.telegraf_plugin_input_system import TelegrafPluginInputSystem
from influxdb_client.domain.telegraf_plugin_input_tail import TelegrafPluginInputTail
from influxdb_client.domain.telegraf_plugin_output_file import TelegrafPluginOutputFile
from influxdb_client.domain.telegraf_plugin_output_file_config import TelegrafPluginOutputFileConfig
from influxdb_client.domain.telegraf_plugin_output_file_config_files import TelegrafPluginOutputFileConfigFiles
from influxdb_client.domain.telegraf_plugin_output_influx_dbv2 import TelegrafPluginOutputInfluxDBV2
from influxdb_client.domain.telegraf_plugin_output_influx_dbv2_config import TelegrafPluginOutputInfluxDBV2Config
from influxdb_client.domain.telegraf_request import TelegrafRequest
from influxdb_client.domain.telegraf_request_agent import TelegrafRequestAgent
from influxdb_client.domain.telegraf_request_plugin import TelegrafRequestPlugin
from influxdb_client.domain.telegrafs import Telegrafs
from influxdb_client.domain.test_statement import TestStatement
from influxdb_client.domain.threshold import Threshold
from influxdb_client.domain.threshold_base import ThresholdBase
from influxdb_client.domain.threshold_check import ThresholdCheck
from influxdb_client.domain.unary_expression import UnaryExpression
from influxdb_client.domain.unsigned_integer_literal import UnsignedIntegerLiteral
from influxdb_client.domain.user import User
from influxdb_client.domain.user_links import UserLinks
from influxdb_client.domain.users import Users
from influxdb_client.domain.users_links import UsersLinks
from influxdb_client.domain.variable import Variable
from influxdb_client.domain.variable_assignment import VariableAssignment
from influxdb_client.domain.variable_links import VariableLinks
from influxdb_client.domain.variable_properties import VariableProperties
from influxdb_client.domain.variables import Variables
from influxdb_client.domain.view import View
from influxdb_client.domain.view_links import ViewLinks
from influxdb_client.domain.view_properties import ViewProperties
from influxdb_client.domain.views import Views
from influxdb_client.domain.write_precision import WritePrecision
from influxdb_client.domain.xy_geom import XYGeom
from influxdb_client.domain.xy_view_properties import XYViewProperties

from influxdb_client.client.authorizations_api import AuthorizationsApi
from influxdb_client.client.bucket_api import BucketsApi
from influxdb_client.client.labels_api import LabelsApi
from influxdb_client.client.organizations_api import OrganizationsApi
from influxdb_client.client.query_api import QueryApi
from influxdb_client.client.tasks_api import TasksApi
from influxdb_client.client.users_api import UsersApi
from influxdb_client.client.write_api import WriteApi, WriteOptions
from influxdb_client.client.influxdb_client import InfluxDBClient
from influxdb_client.client.write.point import Point

__version__ = '1.2.0'
