# coding: utf-8

"""
    Influx API Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class RoutesQuery(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        '_self': 'str',
        'ast': 'str',
        'analyze': 'str',
        'suggestions': 'str'
    }

    attribute_map = {
        '_self': 'self',
        'ast': 'ast',
        'analyze': 'analyze',
        'suggestions': 'suggestions'
    }

    def __init__(self, _self=None, ast=None, analyze=None, suggestions=None):  # noqa: E501
        """RoutesQuery - a model defined in OpenAPI"""  # noqa: E501

        self.__self = None
        self._ast = None
        self._analyze = None
        self._suggestions = None
        self.discriminator = None

        if _self is not None:
            self._self = _self
        if ast is not None:
            self.ast = ast
        if analyze is not None:
            self.analyze = analyze
        if suggestions is not None:
            self.suggestions = suggestions

    @property
    def _self(self):
        """Gets the _self of this RoutesQuery.  # noqa: E501


        :return: The _self of this RoutesQuery.  # noqa: E501
        :rtype: str
        """
        return self.__self

    @_self.setter
    def _self(self, _self):
        """Sets the _self of this RoutesQuery.


        :param _self: The _self of this RoutesQuery.  # noqa: E501
        :type: str
        """

        self.__self = _self

    @property
    def ast(self):
        """Gets the ast of this RoutesQuery.  # noqa: E501


        :return: The ast of this RoutesQuery.  # noqa: E501
        :rtype: str
        """
        return self._ast

    @ast.setter
    def ast(self, ast):
        """Sets the ast of this RoutesQuery.


        :param ast: The ast of this RoutesQuery.  # noqa: E501
        :type: str
        """

        self._ast = ast

    @property
    def analyze(self):
        """Gets the analyze of this RoutesQuery.  # noqa: E501


        :return: The analyze of this RoutesQuery.  # noqa: E501
        :rtype: str
        """
        return self._analyze

    @analyze.setter
    def analyze(self, analyze):
        """Sets the analyze of this RoutesQuery.


        :param analyze: The analyze of this RoutesQuery.  # noqa: E501
        :type: str
        """

        self._analyze = analyze

    @property
    def suggestions(self):
        """Gets the suggestions of this RoutesQuery.  # noqa: E501


        :return: The suggestions of this RoutesQuery.  # noqa: E501
        :rtype: str
        """
        return self._suggestions

    @suggestions.setter
    def suggestions(self, suggestions):
        """Sets the suggestions of this RoutesQuery.


        :param suggestions: The suggestions of this RoutesQuery.  # noqa: E501
        :type: str
        """

        self._suggestions = suggestions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RoutesQuery):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
