# coding: utf-8

"""
    Influx API Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six
from influxdb_client.domain.check_discriminator import CheckDiscriminator


class CheckBase(CheckDiscriminator):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'org_id': 'str',
        'owner_id': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'query': 'DashboardQuery',
        'status': 'TaskStatusType',
        'every': 'str',
        'offset': 'str',
        'tags': 'list[CheckBaseTags]',
        'description': 'str',
        'status_message_template': 'str',
        'labels': 'list[Label]',
        'links': 'CheckBaseLinks'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'org_id': 'orgID',
        'owner_id': 'ownerID',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'query': 'query',
        'status': 'status',
        'every': 'every',
        'offset': 'offset',
        'tags': 'tags',
        'description': 'description',
        'status_message_template': 'statusMessageTemplate',
        'labels': 'labels',
        'links': 'links'
    }

    def __init__(self, id=None, name=None, org_id=None, owner_id=None, created_at=None, updated_at=None, query=None, status=None, every=None, offset=None, tags=None, description=None, status_message_template=None, labels=None, links=None):  # noqa: E501
        """CheckBase - a model defined in OpenAPI"""  # noqa: E501
        CheckDiscriminator.__init__(self)

        self._id = None
        self._name = None
        self._org_id = None
        self._owner_id = None
        self._created_at = None
        self._updated_at = None
        self._query = None
        self._status = None
        self._every = None
        self._offset = None
        self._tags = None
        self._description = None
        self._status_message_template = None
        self._labels = None
        self._links = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.name = name
        self.org_id = org_id
        if owner_id is not None:
            self.owner_id = owner_id
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        self.query = query
        if status is not None:
            self.status = status
        if every is not None:
            self.every = every
        if offset is not None:
            self.offset = offset
        if tags is not None:
            self.tags = tags
        if description is not None:
            self.description = description
        if status_message_template is not None:
            self.status_message_template = status_message_template
        if labels is not None:
            self.labels = labels
        if links is not None:
            self.links = links

    @property
    def id(self):
        """Gets the id of this CheckBase.  # noqa: E501


        :return: The id of this CheckBase.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CheckBase.


        :param id: The id of this CheckBase.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this CheckBase.  # noqa: E501


        :return: The name of this CheckBase.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CheckBase.


        :param name: The name of this CheckBase.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def org_id(self):
        """Gets the org_id of this CheckBase.  # noqa: E501

        The ID of the organization that owns this check.  # noqa: E501

        :return: The org_id of this CheckBase.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this CheckBase.

        The ID of the organization that owns this check.  # noqa: E501

        :param org_id: The org_id of this CheckBase.  # noqa: E501
        :type: str
        """
        if org_id is None:
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501

        self._org_id = org_id

    @property
    def owner_id(self):
        """Gets the owner_id of this CheckBase.  # noqa: E501

        The ID of creator used to create this check.  # noqa: E501

        :return: The owner_id of this CheckBase.  # noqa: E501
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this CheckBase.

        The ID of creator used to create this check.  # noqa: E501

        :param owner_id: The owner_id of this CheckBase.  # noqa: E501
        :type: str
        """

        self._owner_id = owner_id

    @property
    def created_at(self):
        """Gets the created_at of this CheckBase.  # noqa: E501


        :return: The created_at of this CheckBase.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this CheckBase.


        :param created_at: The created_at of this CheckBase.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this CheckBase.  # noqa: E501


        :return: The updated_at of this CheckBase.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this CheckBase.


        :param updated_at: The updated_at of this CheckBase.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def query(self):
        """Gets the query of this CheckBase.  # noqa: E501


        :return: The query of this CheckBase.  # noqa: E501
        :rtype: DashboardQuery
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this CheckBase.


        :param query: The query of this CheckBase.  # noqa: E501
        :type: DashboardQuery
        """
        if query is None:
            raise ValueError("Invalid value for `query`, must not be `None`")  # noqa: E501

        self._query = query

    @property
    def status(self):
        """Gets the status of this CheckBase.  # noqa: E501


        :return: The status of this CheckBase.  # noqa: E501
        :rtype: TaskStatusType
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CheckBase.


        :param status: The status of this CheckBase.  # noqa: E501
        :type: TaskStatusType
        """

        self._status = status

    @property
    def every(self):
        """Gets the every of this CheckBase.  # noqa: E501

        Check repetition interval.  # noqa: E501

        :return: The every of this CheckBase.  # noqa: E501
        :rtype: str
        """
        return self._every

    @every.setter
    def every(self, every):
        """Sets the every of this CheckBase.

        Check repetition interval.  # noqa: E501

        :param every: The every of this CheckBase.  # noqa: E501
        :type: str
        """

        self._every = every

    @property
    def offset(self):
        """Gets the offset of this CheckBase.  # noqa: E501

        Duration to delay after the schedule, before executing check.  # noqa: E501

        :return: The offset of this CheckBase.  # noqa: E501
        :rtype: str
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this CheckBase.

        Duration to delay after the schedule, before executing check.  # noqa: E501

        :param offset: The offset of this CheckBase.  # noqa: E501
        :type: str
        """

        self._offset = offset

    @property
    def tags(self):
        """Gets the tags of this CheckBase.  # noqa: E501

        List of tags to write to each status.  # noqa: E501

        :return: The tags of this CheckBase.  # noqa: E501
        :rtype: list[CheckBaseTags]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this CheckBase.

        List of tags to write to each status.  # noqa: E501

        :param tags: The tags of this CheckBase.  # noqa: E501
        :type: list[CheckBaseTags]
        """

        self._tags = tags

    @property
    def description(self):
        """Gets the description of this CheckBase.  # noqa: E501

        An optional description of the check.  # noqa: E501

        :return: The description of this CheckBase.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CheckBase.

        An optional description of the check.  # noqa: E501

        :param description: The description of this CheckBase.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def status_message_template(self):
        """Gets the status_message_template of this CheckBase.  # noqa: E501

        The template used to generate and write a status message.  # noqa: E501

        :return: The status_message_template of this CheckBase.  # noqa: E501
        :rtype: str
        """
        return self._status_message_template

    @status_message_template.setter
    def status_message_template(self, status_message_template):
        """Sets the status_message_template of this CheckBase.

        The template used to generate and write a status message.  # noqa: E501

        :param status_message_template: The status_message_template of this CheckBase.  # noqa: E501
        :type: str
        """

        self._status_message_template = status_message_template

    @property
    def labels(self):
        """Gets the labels of this CheckBase.  # noqa: E501


        :return: The labels of this CheckBase.  # noqa: E501
        :rtype: list[Label]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this CheckBase.


        :param labels: The labels of this CheckBase.  # noqa: E501
        :type: list[Label]
        """

        self._labels = labels

    @property
    def links(self):
        """Gets the links of this CheckBase.  # noqa: E501


        :return: The links of this CheckBase.  # noqa: E501
        :rtype: CheckBaseLinks
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this CheckBase.


        :param links: The links of this CheckBase.  # noqa: E501
        :type: CheckBaseLinks
        """

        self._links = links

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckBase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
